summaryrefslogtreecommitdiffstats
path: root/tdeui/krootpixmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/krootpixmap.h')
-rw-r--r--tdeui/krootpixmap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdeui/krootpixmap.h b/tdeui/krootpixmap.h
index 776863c46..bc5518221 100644
--- a/tdeui/krootpixmap.h
+++ b/tdeui/krootpixmap.h
@@ -20,7 +20,7 @@
class TQRect;
class TQWidget;
class TQTimer;
-class KSharedPixmap;
+class TDESharedPixmap;
class KRootPixmapData;
/**
@@ -37,7 +37,7 @@ class KRootPixmapData;
* Instead of using the default behavior, you can ask KRootPixmap
* to emit a backgroundUpdated(const TQPixmap &) signal whenever
* the background needs updating by using setCustomPainting(bool).
* Alternatively by reimplementing updateBackground(KSharedPixmap*)
* you can take complete control of the behavior.
*
* @author Geert Jansen <jansen@kde.org>
@@ -179,7 +179,7 @@ public slots:
void setCustomPainting( bool enable ) { m_bCustomPaint = enable; }
/**
* Asks KDesktop to export the desktop background as a KSharedPixmap.
* This method uses DCOP to call KBackgroundIface/setExport(int).
*/
void enableExports();
@@ -209,7 +209,7 @@ protected:
* applies the fade effect, then sets the target's background, or emits
* backgroundUpdated(const TQPixmap &) depending on the painting mode.
*/
- virtual void updateBackground( KSharedPixmap * );
+ virtual void updateBackground( TDESharedPixmap * );
private slots:
void slotBackgroundChanged(int);
@@ -229,7 +229,7 @@ private:
TQRect m_Rect;
TQWidget *m_pWidget;
TQTimer *m_pTimer;
- KSharedPixmap *m_pPixmap;
+ TDESharedPixmap *m_pPixmap;
KRootPixmapData *d;
void init();
@@ -37,7 +37,7 @@ class KRootPixmapData;
* to emit a backgroundUpdated(const TQPixmap &) signal whenever
* the background needs updating by using setCustomPainting(bool).
- * Alternatively by reimplementing updateBackground(KSharedPixmap*)
+ * Alternatively by reimplementing updateBackground(TDESharedPixmap*)
* you can take complete control of the behavior.
*
@@ -179,7 +179,7 @@ public slots:
void setCustomPainting( bool enable ) { m_bCustomPaint = enable; }
/**
- * Asks KDesktop to export the desktop background as a KSharedPixmap.
+ * Asks KDesktop to export the desktop background as a TDESharedPixmap.
* This method uses DCOP to call KBackgroundIface/setExport(int).
*/